@@ -1,6 +1,5 @@
 '''SQLAlchemy Data Models.'''
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.orm import relation, relationship
 from sqlalchemy import Column, ForeignKey
 from sqlalchemy.types import Numeric, Integer, Text, String, Date, DateTime, Time, Boolean, Enum, Float
 from sqlalchemy import Table
@@ -23,11 +22,4 @@ class Model(Base):
     updated_at = Column(DateTime(timezone=True), server_default=func.now(), server_onupdate=func.now())
 
 class View(Base):
-    __abstract__ = True
-
-
-class Team(Model):
-    __tablename__ = 'teams'
-    __keys__ = 'name'
-
-    name = Column(String(255), unique=True)
\ No newline at end of file
+    __abstract__ = True
\ No newline at end of file
