@@ -11,14 +11,14 @@ class Parser:
         self.scraper = self.get_scraper(config=config, headless=headless, fullscreen=fullscreen, disable_javascript=disable_javascript, window=window, user_dir=user_dir, proxy_address=proxy_address)
 
     # region methods
-    def click(self, path: str, element: any=None, timeout: int=0, pos: int=0) -> any:
-        return self.scraper.click(path=path, element=element, timeout=timeout, pos=pos)
+    def click(self, path: str, element: any=None, timeout: int=0, pos: int=0, is_error: bool=True) -> any:
+        return self.scraper.click(path=path, element=element, timeout=timeout, pos=pos, is_error=is_error)
 
-    def hover(self, path: str, element: any=None) -> None:
-        self.scraper.hover(path=path, element=element)
+    def hover(self, path: str, element: any=None, is_error: bool=True) -> None:
+        self.scraper.hover(path=path, element=element, is_error=is_error)
 
-    def click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0) -> None:
-        return self.scraper.click_and_hold(path=path, element=element, timeout=timeout, seconds=seconds)
+    def click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0, is_error: bool=True) -> None:
+        return self.scraper.click_and_hold(path=path, element=element, timeout=timeout, seconds=seconds, is_error=is_error)
 
     def back(self) -> None:
         self.scraper.back()
@@ -26,26 +26,26 @@ class Parser:
     def get_current_url(self) -> str:
         return self.scraper.get_current_url()
 
-    def enter_text(self, path: str, text: str, clear: bool=False, element: any=None, timeout: int=0):
-        return self.scraper.enter_text(path=path, text=text, clear=clear, element=element, timeout=timeout)
+    def enter_text(self, path: str, text: str, clear: bool=False, element: any=None, timeout: int=0, is_error: bool=True):
+        return self.scraper.enter_text(path=path, text=text, clear=clear, element=element, timeout=timeout, is_error=is_error)
 
     def wget(self, url: str, tries: int=0):
         return self.scraper.wget(url, tries)
 
-    def xPath(self, path: str, element: any=None, pos: int=None, dataType: str=None, prop: str=None, explode=None, condition=None, substring=None, transform=None, replace=None, join=None, timeout=0):
-        return self.scraper.xPath(path=path, element=element, pos=pos, dataType=dataType, prop=prop, explode=explode, condition=condition, substring=substring, transform=transform, replace=replace, join=join, timeout=timeout)
+    def xPath(self, path: str, element: any=None, pos: int=None, dataType: str=None, prop: str=None, explode=None, condition=None, substring=None, transform=None, replace=None, join=None, timeout=0, is_error: bool=True):
+        return self.scraper.xPath(path=path, element=element, pos=pos, dataType=dataType, prop=prop, explode=explode, condition=condition, substring=substring, transform=transform, replace=replace, join=join, timeout=timeout, is_error=is_error)
 
-    def exists(self, path: str, element: any=None, timeout: int=0):
-        return self.scraper.exists(path=path, element=element, timeout=timeout)
+    def exists(self, path: str, element: any=None, timeout: int=0, is_error: bool=True):
+        return self.scraper.exists(path=path, element=element, timeout=timeout, is_error=is_error)
 
     def get_css(self, element: any, prop: str):
         return self.scraper.get_css(element=self, prop=prop)
 
-    def login(self, username_text: str=None, username: str=None, password_text: str=None, password: str=None) -> None:
-        self.scraper.login(username_text, username, password_text, password)
+    def login(self, username_text: str=None, username: str=None, password_text: str=None, password: str=None, is_error: bool=True) -> None:
+        self.scraper.login(username_text, username, password_text, password, is_error=is_error)
 
-    def search(self, path: str=None, text: str=None, timeout: int=0) -> None:
-        self.scraper.search(path=path, text=text, timeout=timeout)
+    def search(self, path: str=None, text: str=None, timeout: int=0, is_error: bool=True) -> None:
+        self.scraper.search(path=path, text=text, timeout=timeout, is_error=is_error)
 
     def scroll_to_bottom(self) -> None:
         self.scraper.scroll_to_bottom()
