@@ -23,12 +23,12 @@ class Scraper:
             time.sleep(3)
             return self.wget(url, tries)
 
-    def xPath(self, path, element=None, pos=0, dataType=None, prop=None, explode=None, condition=None, substring=None, transform=None, replace=None, join=None, timeout=0):
+    def xPath(self, path, element=None, pos=0, dataType=None, prop=None, explode=None, condition=None, substring=None, transform=None, replace=None, join=None, timeout=0, is_error: bool=True):
         if path is None or path == '':
             return None
 
         element = self.parser if element is None else element
-        el = self.on_xPath(element=element, path=path, timeout=timeout)
+        el = self.on_xPath(element=element, path=path, timeout=timeout, is_error=is_error)
 
         # step 1: extract xpath
         if el is None:
@@ -111,8 +111,8 @@ class Scraper:
 
         return el
 
-    def exists(self, path: str, element: any=None, timeout: int=0):
-        return self.on_exists(path=path, element=element, timeout=timeout)
+    def exists(self, path: str, element: any=None, timeout: int=0, is_error: bool=False):
+        return self.on_exists(path=path, element=element, timeout=timeout, is_error=is_error)
 
     def substring(self, el: any, substring: str):
         if substring is not None and el is not None:
@@ -199,17 +199,17 @@ class Scraper:
             return eval('element ' + condition)
         '''
 
-    def hover(self, path: str, element: any=None) -> None:
-        self.on_hover(path=path, element=element) 
+    def hover(self, path: str, element: any=None, is_error: bool=True) -> None:
+        self.on_hover(path=path, element=element, is_error=is_error) 
 
     def enter_text(self, path: str, text: str, element: any=None, clear: bool=False, timeout: int=0):
         return self.on_enter_text(path=path, text=text, element=element, clear=clear, timeout=timeout)
 
-    def click(self, path: str, element: any=None, timeout: int=0, pos: int=0) -> any:
-        return self.on_click(path=path, element=element, timeout=timeout, pos=pos)
+    def click(self, path: str, element: any=None, timeout: int=0, pos: int=0, is_error: bool=True) -> any:
+        return self.on_click(path=path, element=element, timeout=timeout, pos=pos, is_error=is_error)
 
-    def click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0) -> None:
-        self.on_click_and_hold(path=path, seconds=seconds, element=element, timeout=timeout)
+    def click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0, is_error: bool=True) -> None:
+        self.on_click_and_hold(path=path, seconds=seconds, element=element, timeout=timeout, is_error=is_error)
 
     def back(self):
         self.on_back()
