@@ -91,19 +91,20 @@ class Selenium(Scraper):
         self.driver.get(url)
         return self.driver
 
-    def on_xPath(self, path, element=None, timeout=0):
+    def on_xPath(self, path, element=None, timeout=0, is_error: bool=True):
 
         try:
             el = self.on_exists(element=element, path=path, timeout=timeout)
-            if el != False:
+            if el is True:
                 return (self.driver if element is None else element).find_elements(by=By.XPATH, value=path)
             else:
                 return None
         
-        except NoSuchElementException:
-            return None
+        except NoSuchElementException as ex:
+            if is_error is False: return None
+            else: raise ex
 
-    def on_exists(self, path, element, timeout=0):
+    def on_exists(self, path, element, timeout=0, is_error: bool=True):
         element = self.driver if element is None else element
 
         if timeout > 0:
@@ -112,14 +113,21 @@ class Selenium(Scraper):
                 return WebDriverWait(driver=element, timeout=timeout, ignored_exceptions=ignored_exceptions).until(
                     EC.presence_of_element_located((By.XPATH, path))
                 )
-            except Exception as e:
-                return False
+            except Exception as ex:
+                if is_error is True:
+                    raise ex
+                else: return False
         else:
             try:
-                return len(element.find_elements(by=By.XPATH, value=path)) > 0
+                if is_error is False:
+                    return len(element.find_elements(by=By.XPATH, value=path)) > 0
+                elif is_error is True and len(element.find_elements(by=By.XPATH, value=path)) == 0:
+                    raise NoSuchElementException(msg=f'Element with xpath {path} was not found')
 
-            except NoSuchElementException:
-                return False
+            except NoSuchElementException as ex:
+                if is_error is True:
+                    raise ex
+                else: return False
             except StaleElementReferenceException:
                 raise StaleElementReferenceException()
 
@@ -132,8 +140,8 @@ class Selenium(Scraper):
     def on_get_attribute(self, element, prop):
         return element.get_attribute(prop)
 
-    def click_all(self, path: str, element: any=None, timeout=0) -> None:
-        elements = self.xPath(path=path, element=element, timeout=timeout)
+    def click_all(self, path: str, element: any=None, timeout=0, is_error: bool=True) -> None:
+        elements = self.xPath(path=path, element=element, timeout=timeout, is_error=is_error)
         if elements is not None:
 
             try:
@@ -152,20 +160,20 @@ class Selenium(Scraper):
         else:
             return None
 
-    def on_hover(self, path: str, element: any) -> None:
-        element = self.xPath(element=element, path=path)
+    def on_hover(self, path: str, element: any, is_error: bool=True) -> None:
+        element = self.xPath(element=element, path=path, is_error=is_error)
         ActionChains(self.driver).move_to_element(element).perform()
 
-    def on_click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0) -> None:
-        element = self.xPath(path=path, timeout=timeout)
+    def on_click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0, is_error: bool=True) -> None:
+        element = self.xPath(path=path, timeout=timeout, is_error=is_error)
         action = ActionChains(self.driver)
         action.click_and_hold(element).perform()
         time.sleep(seconds) # sleep for N seconds
         action.release().perform()
 
-    def on_click(self, path: str, element: any=None, timeout: int=0, pos: int=0) -> any:
+    def on_click(self, path: str, element: any=None, timeout: int=0, pos: int=0, is_error: bool=True) -> any:
         if element is None and path is not None:
-            element = self.xPath(path=path, element=element, timeout=timeout, pos=pos)
+            element = self.xPath(path=path, element=element, timeout=timeout, pos=pos, is_error=is_error)
         
         if element is not None:
             if type(element) is list:
@@ -218,8 +226,8 @@ class Selenium(Scraper):
     def on_get_current_url(self):
         return self.driver.current_url
 
-    def on_enter_text(self, path: str, text: str, clear: bool=False, element: any=None, timeout: int=0):
-        element = self.on_xPath(path=path, element=element, timeout=timeout)
+        element = self.on_xPath(path=path, element=element, timeout=timeout, is_error=is_error)
+    def on_enter_text(self, path: str, text: str, clear: bool=False, element: any=None, timeout: int=0, is_error: bool=True):
         if element is not None:
             if type(element) is list:
                 element = element[0]
@@ -233,18 +241,18 @@ class Selenium(Scraper):
         else:
             return False
 
-    def on_solve_captcha(self, path):
+    def on_solve_captcha(self, path: str):
         pass
 
-    def on_login(self, username_text=None, username=None, password_text=None, password=None):
-        self.on_enter_text(username_text, username)
-        self.on_enter_text(password_text, password)
+    def on_login(self, username_text=None, username=None, password_text=None, password=None, is_error: bool=True):
+        self.on_enter_text(username_text, username, is_error=is_error)
+        self.on_enter_text(password_text, password, is_error=is_error)
 
         self.on_click('//button[@class="sign-in-form__submit-button"]')
 
-    def on_search(self, path=None, text=None, timeout: int=0):
-        self.on_enter_text(path=path, text=text, timeout=timeout)
-        return self.on_enter_text(path=path, text=Keys.RETURN, timeout=timeout)
+    def on_search(self, path=None, text=None, timeout: int=0, is_error: bool=True):
+        self.on_enter_text(path=path, text=text, timeout=timeout, is_error=is_error)
+        return self.on_enter_text(path=path, text=Keys.RETURN, timeout=timeout, is_error=is_error)
 
     def on_scroll_to_bottom(self):
         self.driver.execute_script('window.scrollTo(0, document.body.scrollHeight);')
